extractor.KeywordExtractor

|  | ## Cheshire3 Object Model: Class KeywordExtractor

Module extractor :: Class KeywordExtractor

## Class KeywordExtractor
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
        baseObjects.Extractor --+
                                |
                  SimpleExtractor --+
                                    |
                                   KeywordExtractor

Known Subclasses:
  ProximityExtractor

Extracts keywords from the text
Instance Methods

__init__(self, session, parser, config) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
_keywordify(self, session, data)
process_string(self, session, data) Process a raw string, eg from an attribute value or the query.
process_node(self, session, data) Process a DOM node.
process_eventList(self, session, data) Process a list of SAX events serialised in C3 internal format.
Inherited from `SimpleExtractor`: `process_xpathResult` Inherited from `SimpleExtractor` (private): `_mergeHash` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, parser, config) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: SimpleExtractor.__init__

### _keywordify(self, session, data) | source code

### process_string(self, session, data) | source code
Process a raw string, eg from an attribute value or the query. Overrides: SimpleExtractor.process_string

### process_node(self, session, data) | source code
Process a DOM node. Overrides: SimpleExtractor.process_node

### process_eventList(self, session, data) | source code
Process a list of SAX events serialised in C3 internal format. Overrides: SimpleExtractor.process_eventList